import { DownloadQueryResultsOptions, DownloadQueryResultsResult, DownloadTableCSVData, DownloadTableData, DownloadTableMemoryData, DriverInterface, ExternalDriverCompatibilities, IndexesSQL, QueryOptions, TableColumn, TableStructure } from '@cubejs-backend/query-orchestrator';
import { Config } from 'arangojs/connection';
import { ArangoDbQuery } from './arangodb-query';
export declare type TableMap = Record<string, TableColumn[]>;
export declare type SchemaStructure = Record<string, TableMap>;
export default class ArangoDbDriver implements DriverInterface {
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    static driverEnvVariables(): string[];
    static dialectClass(): typeof ArangoDbQuery;
    private config;
    private client;
    constructor(config?: Config);
    testConnection(): Promise<any>;
    release(): Promise<void>;
    readOnly(): boolean;
    tablesSchema(): Promise<{}>;
    createSchemaIfNotExists(schemaName: string): Promise<any>;
    uploadTableWithIndexes(table: string, columns: TableStructure, tableData: DownloadTableData, indexesSql: IndexesSQL, uniqueKeyColumns: string[], queryTracingObj: any): Promise<void>;
    loadPreAggregationIntoTable: (preAggregationTableName: string, loadSql: string, params: any, options: any) => Promise<any>;
    query<R = unknown>(query: string, params: unknown[], options?: QueryOptions): Promise<R[]>;
    tableColumnTypes: (table: string) => Promise<TableStructure>;
    getTablesQuery: (schemaName: string) => Promise<{
        table_name?: string;
        TABLE_NAME?: string;
    }[]>;
    dropTable: (tableName: string, options?: QueryOptions) => Promise<unknown>;
    downloadQueryResults: (query: string, values: unknown[], options: DownloadQueryResultsOptions) => Promise<DownloadQueryResultsResult>;
    downloadTable: (table: string, options: ExternalDriverCompatibilities) => Promise<DownloadTableMemoryData | DownloadTableCSVData>;
    nowTimestamp(): number;
    quoteIdentifier(identifier: string): string;
    private aggrAttrs;
    private toGenericType;
}
//# sourceMappingURL=arangodb-driver.d.ts.map